/*
 * Copyright (C) 2012 - Michael Baudin
 * Copyright (C) 2011 - DIGITEO - Michael Baudin
 * Copyright (C) 2008 - INRIA
 *
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */
 
#ifndef _CDFLIB_H_PRIV_
#define _CDFLIB_H_PRIV_

#define min(a,b) ((a) <= (b) ? (a) : (b))
#define max(a,b) ((a) >= (b) ? (a) : (b))
#define TRUE_ (1)
#define FALSE_ (0)
#define Abs(x) ( ( (x) >= 0) ? (x) : -( x) )

// If this function is non-NULL, it is used to generate uniform random numbers in [0,1).
// It can be configure with the public function "genrand_randSetFunction".
extern double (* genrand_randfunction)();

// If this function is non-NULL, it is used to generate uniform random integers in [a,b].
// It can be configure with the public function "genrand_randIntegerInRangeSetFunction".
extern double (* genrand_randIntegerInRange)(double *a, double *b);

// If this function is non-NULL, it is used to print messages out.
// It can be configure with the public function "unifrng_msgsetfunction".
// If the function is not configured, the messages are printed in the console.
extern void (* genrand_messagefunction)(char * message);

// Print error messages
void genrand_messageprint(char * msg);

// The function which generates random numbers uniform in [0,1).
double genrand_randgenerate();

// The function which generates random integers uniform in [a,b].
double genrand_generateIntegerInRange(double *a, double *b);

// Standard Exponential Random Variable
double genrand_sexpo ();

// Standard Gamma Random Variable
double genrand_sgamma (double a);

// Generate Standard Normal Random Variables
double genrand_snorm();

//
// Elementary Functions
//

// Computes log(1+x) accurately for small x
double genrand_logp1(double x);

//  Compute   v = log ( (1 + s)/(1 - s) )  for small s, this is for |s| < SLIM = 0.20
double genrand_lnp1m1(double s);

//
// Numerical Linear Algebra
//

// Scalar product of vectors sx and sy
double genrand_sdot (int *n, double *sx, int *incx, double *sy, int *incy);

// Factors a symmetric positive definite matrix
int genrand_spofa (double *a, int *lda, int *n, int *info);

// THE MACHINE PRECISION
double genrand_doubleEps();

// THE SMALLEST MAGNITUDE
double genrand_doubleTiny();

// THE LARGEST MAGNITUDE
double genrand_doubleHuge();

// Inf
double cdflib_doubleInfinite();

#endif /** _CDFLIB_H_PRIV_   **/

