
// Copyright (C) 2012 - Michael Baudin
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

//
// gwsupport.h
//   Header for the C gateway support functions for DISTFUN
//
#ifndef __SCI_GWSUPPORT_H__
#define __SCI_GWSUPPORT_H__

#ifdef _MSC_VER
	#if LIBGWSUPPORT_EXPORTS 
		#define GWSUPPORT_IMPORTEXPORT __declspec (dllexport)
	#else
		#define GWSUPPORT_IMPORTEXPORT __declspec (dllimport)
	#endif
#else
	#define GWSUPPORT_IMPORTEXPORT
#endif

#undef __BEGIN_DECLS
#undef __END_DECLS
#ifdef __cplusplus
# define __BEGIN_DECLS extern "C" {
# define __END_DECLS }
#else
# define __BEGIN_DECLS /* empty */
# define __END_DECLS /* empty */
#endif

__BEGIN_DECLS

static int GWSUPPORT_OK = 1;
static int GWSUPPORT_ERROR = 0;

// Check size
int gwsupport_CheckSize ( char * fname , int ivar , int expected_nrows , int expected_ncols , int actual_nrows , int actual_ncols );

// Create LHS matrix of doubles
int gwsupport_AllocateLhsMatrixOfDoubles ( int ivar , int nRows , int nCols , double ** matrix );

// Get real matrix of doubles
int gwsupport_GetRealMatrixOfDoubles( char * fname, int ivar , double** lrA, int * mA , int * nA );

// Get scalar double
int gwsupport_GetScalarDouble( char * fname, int ivar , double* lrA );

// Integer
int gwsupport_GetOneIntegerArgument ( char * fname , int ivar , int * value );
int gwsupport_Double2IntegerArgument ( char * fname , int ivar , double dvalue , int * ivalue );
int gwsupport_CheckDoubleHasIntegerValue ( char * fname , int ivar , double dvalue );
int gwsupport_CheckDoubleMatrixHasIntegerValue ( char * fname , int ivar , double * p, int nrows , int ncols );

// Check Range
int gwsupport_CheckDoubleInRange (char *fname, int ivar, double mydouble, double mindouble, double maxdouble);
int gwsupport_CheckDoubleMatrixInRange (char *fname, int ivar, double* lrA, int mA , int nA, double mindouble, double maxdouble);

// Check >=
int gwsupport_CheckDoubleGreaterOrEqual (char *fname, int ivar, double value, double mindouble);
int gwsupport_CheckDoubleMatrixGreaterOrEqual (char *fname, int ivar, double* lrA, int mA , int nA, 
	double mindouble);
// Check >
int gwsupport_CheckDoubleGreaterThan (char *fname, int ivar, double value, double mindouble);
int gwsupport_CheckDoubleMatrixGreaterThan (char *fname, int ivar, double* lrA, int mA , int nA, 
	double mindouble);

// Get > or >=
int gwsupport_GetMatrixOfDoublesGreaterOrEqualThanZero( char * fname, int ivar , double** lrA, int * rowsA , int * colsA	);
int gwsupport_GetMatrixOfDoublesGreaterThanZero( char * fname, int ivar , double** lrA, int * rowsA , int * colsA	);

// Prints a warning message
void gwsupport_PrintWarning ( char * message );

// Get scalar string
int gwsupport_GetScalarString( char * fname, int ivar , char** mystring );

__END_DECLS


/* ==================================================================== */

#endif /* __SCI_GWSUPPORT_H__ */
