// =============================================================================
// Copyright (C) 2012 - Michael Baudin
// Copyright (C) 2008 - INRIA - Sabine Gaüzere
// Copyright (C) 2010 - DIGITEO - Michael Baudin
// 
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http:// www.cecill.info/licences/Licence_CeCILL_V2-en.txt
// =============================================================================
// <-- TEST WITH GRAPHIC -->

// 
// These tests makes comparisons between the empirical cumulated 
// distribution function and the theoretical distribution function.
// They do not make use of the Chi-square distribution function,
// and, therefore, are not Kolmogorov-Smirnov tests.
// The tester is asked to visually compare the two plots, which 
// cannot be automated.
// 

// Comparison of pseudo-random numbers following an exponential distribution 
// and the density of this distribution
// Parameter of the distribution which can be modified
f=scf();
lambda=1.6;
// Number of random variable generated
N=100000;
// Generation of a vector of numbers following an exponential distribution
X = distfun_grandexp(1,N,lambda);
// Discretisation of the abscisses in classes
classes = linspace(0,12,25);
// Draw in histogram
histplot(classes,X)
// Draw the density 
x=linspace(0,12,25);
y = distfun_exppdf(x,lambda);
plot(x,y);
delete(f);

// Comparison of pseudo-random numbers following a beta distribution 
// and the density of this distribution
// Parameters of the distribution which can be modified
f=scf();
A=1;
B=3;
// Number of random variable generated
N=100000;
// Generation of a vector of numbers following a beta distribution
X = distfun_grandbet(1,N,A,B);
// Discretisation of the abscisses in classes
classes = linspace(0,1,50);
// Draw in histogram
histplot(classes,X)
// Draw the density 
x=linspace(0,1,50);
y = distfun_betapdf(x,A,B);
plot(x,y);
delete(f);

// Comparison of pseudo-random numbers following a gamma distribution 
// and the density of this distribution
// Parameters of the distribution which can be modified
f=scf();
A=2;
B=1;
//  Number of random variable generated
N=100000;
// Generation of a vector of numbers following a gamma distribution
X = distfun_grandgam(1,N,A,B);
// Discretisation of the abscisses in classes
classes = linspace(0,2,50);
// Draw in histogram
histplot(classes,X)
// Draw the density 
x=linspace(0,2,50);
y = distfun_gampdf(x,A,B);
plot(x,y);
delete(f);


// Comparison of pseudo-random numbers following a binomial distribution 
// and the density of this distribution
// Parameters of the distribution which can be modified
n=50;
p=0.3;
// Number of random variable generated
N=100000;
// Generation of a vector of numbers following a binomial distribution
X = distfun_grandbin(1,N,n,p);
f=scf();
// Discretisation of the abscisses in classes
classes = linspace(0,n,n+1);
// Draw in histogram
histplot(classes,X)
// Draw the density
x=linspace(0,n,n+1);
y = binomial(p,n);
plot(x,y);
delete(f);

// Comparison of pseudo-random numbers following a poisson distribution 
// and the density of this distribution
// Parameters of the distribution which can be modified
mu=50;
// Number of random variable generated
N=100000;
// Generation of a vector of numbers following a poisson distribution
X = distfun_grandpoi(1,N,mu);
f=scf();
// Discretisation of the abscisses in classes
classes = linspace(0,2*mu,101);
// Draw in histogram
histplot(classes,X)
// Draw the density
[x]=linspace(0,2*mu,101);
y = exp(-mu).*(mu^x)./factorial(x);
plot(x,y);
delete(f);


